@@ -3,9 +3,9 @@ package Number::ZipCode::JP::Table::Company;
 use strict;
 use warnings;
 
-our $VERSION = '0.20251226';
+our $VERSION = '0.20260130';
 
-# Table last modified: 2025-12-26
+# Table last modified: 2026-01-30
 our %ZIP_TABLE = (
     '001' => '(?:8(?:5(?:[0-2]1|55|77|88)|612))',
     '002' => '(?:850[1-4])',
@@ -71,7 +71,7 @@ our %ZIP_TABLE = (
     '065' => '(?:8(?:5(?:[34]3|22|67|78|1[018]|5[058]|0[18])|6(?:0[19]|3[139]|1[0-2])))',
     '066' => '(?:8(?:5(?:20|33|67|1[025]|7[07]|8[58]|5[0578]|0[1248])|6(?:01|22|49|55|86|3[379]|6[068]|1[01])|7(?:11|65|87)))',
     '067' => '(?:8(?:5(?:[05]1|47|85|6[45])|674))',
-    '068' => '(?:(?:8(?:6(?:[03]9|42|50|6[068]|8[68])|5(?:11|88|5[058]))|1(?:19[2-5]|292)|0(?:194|492)|219[2-4]))',
+    '068' => '(?:(?:8(?:6(?:[03]9|42|50|86|6[068])|5(?:11|88|5[058]))|1(?:19[2-5]|292)|0(?:194|492)|219[2-4]))',
     '069' => '(?:(?:1(?:29[236-8]|39[2-5])|85(?:[01]1|[58]5|33)|029[23]))',
     '070' => '(?:8(?:6(?:[02]1|[67][06]|1[0-26]|5[013]|8[068]|3[069]|4[0-24])|5(?:[35]0|2[015]|0[2357]|6[07]|1[05]|4[01])|7(?:01|70|2[02]|1[01])))',
     '071' => '(?:(?:0(?:19[28]|29[28]|59[67]|79[58])|1(?:49[2-7]|29[2358]|59[236])))',
@@ -105,8 +105,8 @@ our %ZIP_TABLE = (
     '099' => '(?:(?:2(?:19[2-8]|49[235]|392)|1(?:49[2568]|19[78]|595)|3(?:29[23]|69[78])|4(?:19[256]|492)|(?:56|65)92|049[245]))',
     '100' => '(?:(?:8(?:9(?:4[015]|3[0-37]|8[0-3679]|9[46]|2[0-24679]|1[02-9]|6[0-57-9]|0[1-579]|5[0-35689]|7[013-9])|1(?:7[2468]|1[0137-9]|8[124-9]|2[013-8]|0[1-57-9]|6[05689]|4[0-24]|5[0-24589]|3[0-69])|2(?:28|51|70|0[1357]|8[23578]|3[2-5]|1[4-69]|4[156]|6[0258])|3(?:70|5[015]|3[2358]|2[1245]|0[2367]|4[15]|1[01]|8[038])|5(?:11|4[03]|6[07]|[58][58]|7[57]|2[0-2]|0[235-7])|6(?:55|2[019]|3[19]|6[356]|7[67]|1[07]|0[126]|4[049])|4(?:5[06]|1[015]|2[47]|3[09]|0[235]|[48][48])|0(?:19|5[015]|7[07-9]|8[068]|6[56])|79[1-4])|6(?:1(?:62|7[0-57]|5[0-2])|2(?:55|77|6[02])|0(?:51|66|80)|75[1-6])|149[28]))',
     '101' => '(?:8(?:6(?:8[28]|0[356]|5[146]|6[57]|2[1246-9]|3[01367]|7[026]|4[235-8]|1[01679])|4(?:1[0568]|6[0-246]|7[057]|4[13-68]|3[0379]|8[05]|0[58]|2[12459]|5[0169])|5(?:3[0-245]|6[1258]|7[59]|4[28]|1[25]|0[249]|8[0569]|2[0-578]|5[24589])|3(?:5[013589]|8[38]|4[367]|0[17-9]|3[3568]|1[0138]|2[3-69]|7[258]|6[267])|7(?:0[137]|1[0-25-8])|9(?:41|50|7[37]|8[36])|2(?:28|0[14]|1[0359])|0(?:11|5[04]|0[128])|1(?:01|89)))',
-    '102' => '(?:8(?:1(?:1[0-357-9]|2[02-58]|8[124-8]|0[239]|5[0-25]|3[0-289]|7[0-25-8]|9[0-5]|4[0-24]|6[016])|5(?:0[2-468]|4[013]|5[2-9]|7[01378]|3[0-39]|2[02589]|1[0-3569]|6[013-79]|8[023568])|6(?:3[0-3579]|4[2-5]|2[0-26-8]|8[0589]|5[156]|7[17-9]|1[0-47-9]|6[06-8]|0[1-4679])|4(?:7[047]|6[0-24-68]|5[0-259]|0[124-7]|4[0158]|1[0-2479]|2[0146]|8[489]|3[037])|2(?:5[015]|3[0-24-68]|6[045]|8[28]|7[2-57]|2[1-68]|[01][15]|4[016])|3(?:4[13]|7[0-37]|3[1-36]|2[124]|1[0134]|8[1-38]|6[24]|5[0367]|0[1359])|0(?:30|77|8[0-358]|2[256]|5[05]|0[58]|1[125689])|7(?:30|9[58])|811))',
-    '103' => '(?:8(?:2(?:5[0-2569]|3[0-689]|7[036-8]|0[1-68]|8[2457]|1[0-248]|6[0156]|2[124589]|4[013578])|4(?:7[0-3]|0[1-57]|6[0-24-68]|4[38]|3[0-589]|1[0-79]|2[24-7]|8[02457-9]|5[016])|3(?:70|0[1378]|8[0348]|4[15-7]|1[1-478]|5[0-248]|6[036]|3[01357-9]|2[13-58])|5(?:1[0-257]|5[12468]|7[17]|2[0-25]|0[1-356]|6[67]|8[4-68]|3[4-8]|4[238])|6(?:40|5[0136]|3[169]|7[67]|6[068]|8[0469])|0[01]1))',
+    '102' => '(?:8(?:1(?:1[0-357-9]|2[02-58]|8[124-8]|0[239]|5[0-25]|3[0-289]|7[0-25-8]|9[0-5]|4[0-24]|6[016])|5(?:0[2-468]|4[013]|5[2-9]|7[01378]|3[0-39]|2[02589]|1[0-3569]|6[013-79]|8[023568])|6(?:3[0-3579]|4[2-5]|2[0-26-8]|8[0589]|5[156]|7[17-9]|1[0-47-9]|6[06-8]|0[1-4679])|4(?:7[047]|6[0-24-68]|5[0-259]|4[0158]|0[125-7]|1[0-2479]|2[0146]|8[489]|3[037])|2(?:5[015]|3[0-24-68]|6[045]|8[28]|7[2-57]|2[1-68]|[01][15]|4[016])|3(?:4[13]|7[0-37]|3[1-36]|2[124]|1[0134]|8[1-38]|6[24]|5[0367]|0[1359])|0(?:30|77|8[0-358]|2[256]|5[05]|0[58]|1[125689])|7(?:30|9[58])|811))',
+    '103' => '(?:8(?:2(?:5[0-2569]|3[0-689]|7[036-8]|0[1-68]|8[2457]|1[0-248]|6[0156]|2[124589]|4[013578])|4(?:7[0-3]|0[1-57]|4[38]|3[0-589]|1[0-79]|2[24-7]|6[0-24-6]|8[02457-9]|5[016])|3(?:70|0[1378]|8[0348]|4[15-7]|1[1-478]|5[0-248]|6[036]|3[01357-9]|2[13-58])|5(?:1[0-257]|5[12468]|7[17]|2[0-25]|0[1-356]|6[67]|8[4-68]|3[4-8]|4[238])|6(?:40|5[0136]|3[169]|7[67]|6[068]|8[0469])|0[01]1))',
     '104' => '(?:(?:8(?:3(?:5[0-356]|1[023579]|6[356]|7[07-9]|8[013689]|3[02358]|2[1-58]|4[0-5]|0[12467])|1(?:50|65|1[04-68]|3[0-259]|7[014589]|8[389]|2[4589]|4[578]|0[124589])|4(?:5[06]|3[013589]|1[369]|0[24578]|8[168]|4[0349]|2[0-469]|6[078])|5(?:33|77|2[136-8]|4[357]|5[014-689]|6[068]|1[078]|8[1458]|0[1256])|2(?:[03]8|40|71|5[124578]|1[28]|6[236]|8[0-59])|6(?:14|78|5[06]|8[05]|6[15])|0(?:55|77|1[01]|0[1-37]))|6241))',
     '105' => '(?:(?:8(?:4(?:7[0-257]|8[2-6]|5[1-36-8]|3[13-7]|0[1-47-9]|[46][014-9]|2[0347-9]|1[0-24-9])|5(?:6[03578]|1[0-2568]|0[1-357-9]|5[013-8]|8[0-57-9]|7[4-9]|2[1-57-9]|3[0457]|4[03-6])|6(?:7[026-8]|3[04]|8[01569]|6[0568]|1[013-5]|2[0135-7]|5[468]|4[0-24]|0[3468])|3(?:1\d|4[0-7]|3[01358]|0[1-9]|2[235])|0(?:10|39|55|0[1258]|7[07]|8[58])|7(?:88|0[127]|1[267]))|7(?:0(?:[58]0|77)|36[05-7]|444)|6[09]50))',
     '106' => '(?:(?:8(?:5(?:6[0-35-79]|0[78]|3[17]|1[458]|7[135-8]|2[12]|5[0-25689]|4[145]|8[0157-9])|6(?:77|4[0-2489]|5[25]|1[16]|6[58]|3[0569]|0[18]|2[0256])|0(?:11|39|0[17])|(?:10|79)7|4(?:01|87))|6(?:1(?:61|88)|06[06])))',
@@ -115,7 +115,7 @@ our %ZIP_TABLE = (
     '109' => '(?:8792)',
     '110' => '(?:8(?:5(?:6[0-25-7]|4[01368]|7[5-8]|3[0-4679]|0[1-3579]|1[0135-7]|5[059]|8[02-468]|2[024])|6(?:53|2[0-2568]|6[0259]|3[0158]|4[124-6]|0[259]|8[015-7]|1[04589]|7[35-8])|7(?:8[027]|0[6-8]|1[2-6]|2[235]|3[36])|408|807))',
     '111' => '(?:8(?:6(?:3[01379]|1[0-258]|2[0-358]|7[6-8]|8[1368]|0[2568]|6[16]|5[05]|4[0248])|5(?:43|1[0-2568]|8[058]|5[1568]|7[57]|6[0167]|0[126-8]|2[125]|3[0-59])|7(?:[56]5|21|98|0[178]|1[01])|081))',
-    '112' => '(?:8(?:6(?:90|6[02-48]|4[245]|2[02579]|1[0-289]|7[0178]|5[0-57]|8[0-578]|0[14679]|3[0-5])|5(?:[78][0356]|2[458]|1[124]|6[2369]|3[0138]|0[1-35689]|4[0148]|5[015-8])|7(?:[156]0|78|0[12])|0(?:[01]1|88)|138))',
+    '112' => '(?:8(?:6(?:90|4[245]|2[02579]|1[0-289]|7[0178]|5[0-57]|6[0248]|8[0-578]|0[14679]|3[0-5])|5(?:[78][0356]|2[458]|1[124]|6[2369]|3[0138]|0[1-35689]|4[0148]|5[015-8])|7(?:[156]0|78|0[12])|0(?:[01]1|88)|138))',
     '113' => '(?:8(?:4(?:4[148]|7[1479]|8[3-58]|2[0-3]|1[0-358]|6[2-6]|3[13-5]|5[0169]|0[1248])|5(?:70|0[13-579]|3[04-68]|6[0-46]|4[1369]|1[02379]|2[0145]|5[1356])|6(?:77|3[38]|5[04-8]|0[1-468]|8[16]|1[0-2]|6[0-378])|7(?:01|1[0-29])|139|311))',
     '114' => '(?:8(?:5(?:95|0[1-35-8]|8[013-58]|6[0-25]|2[0-468]|7[147]|4[01356]|5[02-57]|3[0-24589]|1[02457-9])|6(?:11|86|0[2-6])))',
     '115' => '(?:8(?:5(?:55|8[68]|1[01]|2[49])|(?:00|71)1|6(?:22|50)))',
@@ -159,7 +159,7 @@ our %ZIP_TABLE = (
     '167' => '(?:8(?:5(?:[26]0|34|85|0[15-7]|1[05]|5[15])|6(?:10|28|0[12])|001))',
     '168' => '(?:8(?:5(?:[6-8]0|48|1[0-26]|5[058]|2[05]|0[13468]|3[035])|6(?:2[06]|[18][16]|0[18])|081))',
     '169' => '(?:8(?:5(?:8[06]|0[39]|2[0-25-7]|5[0568]|1[6-8]|6[18]|7[078]|4[01]|3[15])|6(?:[23]9|77|5[05]|0[58]|1[0-36]|[46][48])|0(?:50|77|1[12])|7(?:[01]1|22)|(?:88|91)5|228))',
-    '170' => '(?:(?:8(?:4(?:1[015-79]|7[0467]|2[013467]|0[124-69]|4[0-248]|5[015-9]|6[0256]|8[08]|3[02-468])|6(?:[68]6|55|0[25]|3[35])|0(?:55|73)|5(?:51|85))|6080))',
+    '170' => '(?:(?:8(?:4(?:1[015-79]|7[0467]|4[0-2458]|2[013467]|0[124-69]|5[015-9]|6[0256]|8[08]|3[02-468])|6(?:[68]6|55|0[25]|3[35])|0(?:55|73)|5(?:51|85))|6080))',
     '171' => '(?:8(?:5(?:5[23578]|2[0-7]|3[19]|7[027]|4[045]|1[0-268]|6[0189]|0[1-3578]|8[0268])|422))',
     '173' => '(?:8(?:5(?:[06]1|[23]0|4[03]|1[0-25-9]|8[058]|5[258])|6(?:48|3[29]|1[01]|0[1256])|710))',
     '174' => '(?:8(?:5(?:[13]0|0[135]|6[027]|5[058]|2[014-6]|8[08])|6(?:12|46|51|3[0369]|8[068]|0[12])|7(?:[01]1|87|3[079]|4[0134])|860|903))',
@@ -308,7 +308,7 @@ our %ZIP_TABLE = (
     '332' => '(?:8(?:5(?:21|48|77|85|0[1-3]|5[568]|1[12])|6(?:[68]6|01|54)))',
     '333' => '(?:86[01]1)',
     '334' => '(?:8501)',
-    '335' => '(?:8(?:5(?:10|22|33|[58][58]|0[12])|6(?:55|66)))',
+    '335' => '(?:8(?:5(?:10|22|33|0[128]|[58][58])|6(?:55|66)))',
     '336' => '(?:8(?:5(?:40|6[14]|1[25]|2[1-36]|8[67]|[05][58])|6(?:[36]6|55)|760))',
     '337' => '(?:85(?:[58]6|32|70|0[17]))',
     '338' => '(?:8(?:5(?:8[056]|1[0-35]|2[3-5]|7[057]|0[3-68]|6[67]|5[1578]|3[18]|4[01])|6(?:30|86)))',
@@ -433,7 +433,7 @@ our %ZIP_TABLE = (
     '459' => '(?:85(?:[01]1|22|40))',
     '460' => '(?:8(?:5(?:5[01589]|2[0-58]|3[0-24-68]|1[0-7]|8[0568]|6[067]|7[578]|0[13-9]|4[15])|6(?:90|7[0-2489]|2[135-8]|0[2568]|6[05-79]|5[01357]|3[0-3578]|1[04-9]|8[1346-9])|4(?:61|7[057]|2[256]|1[125-7]|0[2-58]|8[1-58]|5[0156]|9[01]|4[0457]|3[0-59])|3(?:02|6[06]|2[015]|5[018]|8[38]|3[0138]|1[0-24589])|7(?:20|0[346-8]|1[18])|20[1-4]))',
     '461' => '(?:8(?:5(?:41|60|8[0-2568]|2[025]|3[0-249]|0[13-8]|7[57]|1[12]|5[08])|6(?:66|80|4[015]|5[01458]|1[02]|0[235]|3[0169]|2[016]|7[0-3568])|7(?:0[367]|2[159]|9[58]|1[0457])))',
-    '462' => '(?:8(?:5(?:30|2[23]|7[5-7]|1[12]|[05][18]|8[08]|4[035])|666|739))',
+    '462' => '(?:8(?:5(?:30|2[23]|7[5-7]|5[158]|1[12]|0[18]|8[08]|4[035])|666|739))',
     '463' => '(?:85(?:10|5[057]|2[128]|8[05]|6[0157]|7[157]|0[1-35]|3[03568]|4[013578]))',
     '464' => '(?:8(?:5(?:85|91|4[05-7]|5[058]|2[0-25]|1[12]|6[0167]|3[01369]|7[017])|6(?:[78]1|0[1-3]|4[134]|3[1-357]|6[12]|1[0135-8]|5[0-24])|710))',
     '465' => '(?:8(?:5(?:20|6[05-7]|5[0-258]|0[15-8]|1[0156])|6(?:68|70|1[0-2]|5[01]|2[026])))',
@@ -456,7 +456,7 @@ our %ZIP_TABLE = (
     '482' => '(?:8(?:5(?:01|55|1[01])|6(?:60|86|5[12])))',
     '483' => '(?:8(?:5(?:55|0[257])|7(?:14|0[14])))',
     '484' => '(?:8(?:5(?:0[1-8]|1[0-2])|609))',
-    '485' => '(?:8(?:5(?:05|1[0-26]|5[0-257]|2[0-3]|3[013]|6[1256])|65[0-5]|750))',
+    '485' => '(?:8(?:5(?:05|1[0-26]|5[0-257]|2[0-3]|3[013]|6[1256])|65[0-5]|75[05]))',
     '486' => '(?:8(?:5(?:01|40|67|2[23]|1[015]|8[58]|5[05]|7[57])|6[68]6))',
     '487' => '(?:8(?:6(?:22|50)|501))',
     '488' => '(?:8(?:5(?:[58]5|01|20|78)|6(?:55|66|8[68])))',
@@ -499,7 +499,7 @@ our %ZIP_TABLE = (
     '527' => '(?:(?:8(?:5(?:[27]7|42|0[158]|8[058]|6[67]|1[12]|5[0458])|687)|0195))',
     '528' => '(?:8(?:5(?:[58]5|0[12]|1[01])|666))',
     '529' => '(?:(?:1(?:3(?:93|8[0-368])|59[2578]|49[235]|69[28]|195|892)|0(?:49[238]|[27]92)))',
-    '530' => '(?:(?:8(?:2(?:4[015]|2[1246-8]|3[0249]|5[0-256]|6[0236]|1[0-8]|7[08]|0[1-79]|8[0-378])|5(?:44|2[1-3]|7[3-578]|6[05-8]|0[1467]|3[15]|1[1-37]|8[023568]|5[0-3568])|3(?:3[348]|0[148]|8[389]|4[16]|2[1-47]|1[08]|5[035])|4(?:59|75|80|1[015]|0[128]|4[18])|6(?:60|1[018]|8[089]|0[1256])|79[136-8])|6070))',
+    '530' => '(?:(?:8(?:2(?:4[015]|2[1246-8]|3[0249]|5[0-256]|6[0236]|1[0-8]|7[08]|0[1-79]|8[0-378])|5(?:44|2[1-3]|7[3-578]|6[05-8]|0[1467]|3[15]|1[1-37]|8[023568]|5[0-3568])|3(?:73|3[348]|0[148]|8[389]|4[16]|2[1-47]|1[08]|5[035])|4(?:59|75|80|1[015]|0[128]|4[18])|6(?:60|1[018]|8[089]|0[1256])|79[136-8])|6070))',
     '531' => '(?:(?:8(?:5(?:[67]7|26|88|0[1-3]|1[019]|5[58])|787)|6053))',
     '532' => '(?:8(?:5(?:35|60|88|2[045]|1[1245]|5[58]|0[1578])|680))',
     '533' => '(?:8(?:5(?:33|85|5[58]|0[12])|651))',
@@ -510,7 +510,7 @@ our %ZIP_TABLE = (
     '538' => '(?:8(?:5(?:[58]5|01|10)|6(?:[68]6|55)))',
     '539' => '(?:8794)',
     '540' => '(?:(?:8(?:5(?:6[06]|4[0147]|5[0-357-9]|2[0-267]|8[15-7]|3[03-5]|0[1578]|7[01578]|1[0-2579])|6(?:86|1[015]|4[25]|2[02]|3[09]|0[2-8]|7[078]|6[08])|795)|6255))',
-    '541' => '(?:(?:8(?:5(?:5[0136-9]|2[013-689]|7[2568]|1[135-9]|4[0-357]|8[1579]|0[1-35689]|6[0136-8]|3[014578])|630|765)|6666))',
+    '541' => '(?:(?:8(?:5(?:5[0136-9]|7[2568]|1[135-9]|2[0-689]|4[0-357]|8[1579]|0[1-35689]|6[0136-8]|3[014578])|630|765)|6666))',
     '542' => '(?:8(?:5(?:33|42|77|0[1-4]|8[0568]|6[67]|2[235]|5[0458]|1[01])|6(?:54|60|8[68])|745))',
     '543' => '(?:8(?:5(?:[34]3|11|0[1-3]|[58][58])|6(?:01|66|8[68])))',
     '544' => '(?:8(?:5(?:[58]5|01)|6[68]6))',
@@ -820,7 +820,7 @@ our %ZIP_TABLE = (
     '859' => '(?:(?:3(?:29[2368]|79[2378]|692)|0(?:49[2578]|19[23])|(?:1[2-5]|6[24])92|4(?:59[5-8]|892)|5(?:39[23]|192)))',
     '860' => '(?:8(?:5(?:3[013469]|8[014-8]|7[057]|[01][1-9]|6[5-8]|5[0-24-8]|4[01357]|2[0-8])|6(?:2[245]|1[1589]|8[168]|5[05]|0[1-68]|6[08])|7(?:39|9[25-7])))',
     '861' => '(?:(?:0(?:59[2-68]|19[58]|69[28]|89[28]|[39]92)|4(?:1(?:89|9[23568])|[34]92|696)|1(?:19[23578]|39[24]|295)|3(?:19[2-6]|29[56]|592)|5(?:49[2-5]|59[28]|292)|85(?:01|14|38|2[089])|2(?:29[35-7]|[14]92)|6[13]95|7292))',
-    '862' => '(?:8(?:6(?:6[06]|7[6-8]|2[02]|3[359]|0[139]|1[0-2]|8[08]|5[125])|7(?:44|1[06]|9[34]|0[12]|2[01])|5(?:[58]5|10|0[2458]|7[01])))',
+    '862' => '(?:8(?:6(?:6[06]|7[6-8]|2[02]|3[359]|0[139]|1[0-2]|8[08]|5[125])|7(?:44|9[34]|0[12]|2[01]|1[016])|5(?:[58]5|10|0[2458]|7[01])))',
     '863' => '(?:(?:8(?:6(?:31|86)|5[58]5)|2(?:292|895)|1992))',
     '864' => '(?:8(?:6(?:11|86)|501))',
     '865' => '(?:(?:85(?:[01]1|33|77|5[05])|019[23]))',
@@ -860,7 +860,7 @@ our %ZIP_TABLE = (
     '899' => '(?:(?:5(?:19[235]|29[2-4]|69[348]|49[25]|392)|6(?:49[2-5]|19[23]|29[23]|592)|2(?:59[2-6]|[127]92)|4(?:39[2-6]|[12]92)|(?:3[14]|7[146])92|0(?:29[23578]|492)|1(?:395|498|696)|8(?:19[23]|692)))',
     '900' => '(?:8(?:5(?:5\d|2[02457]|8[1568]|4[03-578]|1[02-467]|6[07]|3[013-5]|7[01578]|0[13-58])|6(?:10|66|78|0[1-589]|5[014]|8[68])|7(?:[01]1|35|9[4-7])))',
     '901' => '(?:(?:2(?:5(?:40|88|97|0[1267]|6[0679]|1[0-25]|5[0-35-9]|2[0156]|3[01])|6(?:86|0[27]|1[01])|7(?:01|10|33|2[05])|49[2356]|39[235])|0(?:19[2-467]|49[2-6]|29[245]|39[23]|592)|1(?:19[2356]|39[23]|49[25]|292|595)|3(?:[679]92|19[23]|59[25]|496|895)))',
-    '902' => '(?:85(?:21|1[0-3]|8[58]|5[05]|7[01]))',
+    '902' => '(?:85(?:[02]1|1[0-3]|8[58]|5[05]|7[01]))',
     '903' => '(?:(?:02(?:20|1[013478]|0[13-7])|860[1-3]))',
     '904' => '(?:(?:0(?:49[2-7]|39[2-58]|19[2-5]|29[35])|2(?:19[2-46]|29[2-4]|39[2-4])|8(?:5(?:[01]1|85)|686)|1(?:29[2-4]|[13]92)))',
     '905' => '(?:(?:0(?:59[2-6]|79[2-6]|49[24]|292|695)|8(?:5(?:01|12|40|85)|6(?:11|68))|1(?:[23]92|495)|2192))',
